@@ -1,4 +1,3 @@
-import datetime as dt
 import re
 import threading
 import time
@@ -9,6 +8,7 @@ from collections import OrderedDict
 from functools import partial
 
 import requests
+from dateutil.parser import isoparse
 from logbook import Logger
 from represent import ReprHelper, ReprHelperMixin
 from rush.quota import Quota
@@ -32,8 +32,6 @@ enum_re = re.compile(r"""
 
 BASE_URL = 'https://www.space-track.org/'
 
-RATELIMIT_KEY = 'request'
-
 
 class AuthenticationError(Exception):
     """Space-Track authentication error."""
@@ -74,9 +72,9 @@ class Predicate(ReprHelperMixin):
         elif self.type_ == 'int':
             return int(value)
         elif self.type_ == 'datetime':
-            return dt.datetime.strptime(value, '%Y-%m-%d %H:%M:%S')
+            return isoparse(value)
         elif self.type_ == 'date':
-            return dt.datetime.strptime(value, '%Y-%m-%d').date()
+            return isoparse(value).date()
         else:
             return value
 
@@ -88,6 +86,12 @@ class SpaceTrackClient:
         identity: Space-Track username.
         password: Space-Track password.
         base_url: May be overridden to use e.g. https://testing.space-track.org/
+        rush_store: A :mod:`rush` storage backend. By default, a
+            :class:`~rush.stores.dictionary.DictionaryStore` is used. You may
+            wish to use :class:`~rush.stores.dictionary.RedisStore` to
+            follow rate limits from multiple instances.
+        rush_key_prefix: You may choose a prefix for the keys that will be
+            stored in `rush_store`, e.g. to avoid conflicts in a redis db.
 
     For more information, refer to the `Space-Track documentation`_.
 
@@ -131,35 +135,38 @@ class SpaceTrackClient:
     ])
 
     request_controllers['basicspacedata'] = {
+        'announcement',
+        'boxscore',
+        'cdm_public',
+        'decay',
+        'gp',
+        'gp_history',
+        'launch_site',
+        'omm',
+        'satcat',
+        'satcat_change',
+        'satcat_debut',
+        'tip',
         'tle',
         'tle_latest',
         'tle_publish',
-        'omm',
-        'boxscore',
-        'satcat',
-        'launch_site',
-        'satcat_change',
-        'satcat_debut',
-        'decay',
-        'tip',
-        'announcement',
-        'gp',
-        'gp_history',
-        'cdm_public',
     }
 
     request_controllers['expandedspacedata'] = {
+        'car',
         'cdm',
-        'organization',
         'maneuver',
         'maneuver_history',
+        'organization',
+        'satellite',
     }
 
     request_controllers['fileshare'] = {
-        'file',
-        'download',
-        'upload',
         'delete',
+        'download',
+        'file',
+        'folder',
+        'upload',
     }
 
     request_controllers['spephemeris'] = {
@@ -189,7 +196,14 @@ class SpaceTrackClient:
         Predicate('favorites', 'str'),
     }
 
-    def __init__(self, identity, password, base_url=BASE_URL):
+    def __init__(
+        self,
+        identity,
+        password,
+        base_url=BASE_URL,
+        rush_store=None,
+        rush_key_prefix='',
+    ):
         #: :class:`requests.Session` instance. It can be mutated to configure
         #: e.g. proxies.
         self.session = self._create_session()
@@ -213,14 +227,19 @@ class SpaceTrackClient:
         #   your query frequency.
         #   Limit API queries to less than 30 requests per minute / 300 requests
         #   per hour
+        if rush_store is None:
+            rush_store = RushDictionaryStore()
+        limiter = PeriodicLimiter(rush_store)
         self._per_minute_throttle = Throttle(
-            limiter=PeriodicLimiter(RushDictionaryStore()),
+            limiter=limiter,
             rate=Quota.per_minute(30),
         )
         self._per_hour_throttle = Throttle(
-            limiter=PeriodicLimiter(RushDictionaryStore()),
+            limiter=limiter,
             rate=Quota.per_hour(300),
         )
+        self._per_minute_key = rush_key_prefix + 'st_req_min'
+        self._per_hour_key = rush_key_prefix + 'st_req_hr'
 
     def _ratelimit_callback(self, until):
         duration = int(round(until - time.monotonic()))
@@ -431,8 +450,8 @@ class SpaceTrackClient:
 
     def _ratelimited_get(self, *args, **kwargs):
         """Perform get request, handling rate limiting."""
-        minute_limit = self._per_minute_throttle.check(RATELIMIT_KEY, 1)
-        hour_limit = self._per_hour_throttle.check(RATELIMIT_KEY, 1)
+        minute_limit = self._per_minute_throttle.check(self._per_minute_key, 1)
+        hour_limit = self._per_hour_throttle.check(self._per_hour_key, 1)
 
         sleep_time = 0
 
