@@ -601,7 +601,9 @@ def test_dir():
     assert dir(st) == [
         '_authenticated',
         '_controller_proxies',
+        '_per_hour_key',
         '_per_hour_throttle',
+        '_per_minute_key',
         '_per_minute_throttle',
         '_predicates',
         'announcement',
@@ -609,6 +611,7 @@ def test_dir():
         'basicspacedata',
         'boxscore',
         'callback',
+        'car',
         'cdm',
         'cdm_public',
         'decay',
@@ -618,6 +621,7 @@ def test_dir():
         'file',
         'file_history',
         'fileshare',
+        'folder',
         'gp',
         'gp_history',
         'identity',
@@ -630,6 +634,7 @@ def test_dir():
         'satcat',
         'satcat_change',
         'satcat_debut',
+        'satellite',
         'session',
         'spephemeris',
         'tip',
@@ -673,6 +678,14 @@ def test_parse_types():
                     'Null': 'NO',
                     'Type': 'datetime'
                 },
+                {
+                    'Default': None,
+                    'Extra': '',
+                    'Field': 'CREATION_DATE',
+                    'Key': '',
+                    'Null': 'YES',
+                    'Type': 'datetime'
+                },
                 {
                     'Default': '',
                     'Extra': '',
@@ -697,6 +710,8 @@ def test_parse_types():
         json=[{
             # Test a type that is parsed.
             'PUBLISH_EPOCH': '2017-01-02 03:04:05',
+            # Newer classes (e.g. gp) return a different date format
+            'CREATION_DATE': '2017-01-02T03:04:05',
             # Test a type that is passed through.
             'TLE_LINE1': 'The quick brown fox jumps over the lazy dog.',
             # Test a field there was no predicate for.
